==> inventive-inventory-1.3.2-sources.jar: net/inventive_mods/inventive_inventory/config/enums/sorting/SortingMode.java <==
package net.inventive_mods.inventive_inventory.config.enums.sorting;

import net.inventive_mods.inventive_inventory.config.ConfigManager;
import net.inventive_mods.inventive_inventory.config.enums.accessors.Translatable;
import net.inventive_mods.inventive_inventory.util.InteractionHandler;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1887;
import net.minecraft.class_2561;
import net.minecraft.class_7923;
import net.minecraft.class_9304;
import net.minecraft.class_9334;
import java.util.Comparator;
import java.util.stream.Collectors;

public enum SortingMode implements Translatable {
    NAME("name", Comparator.comparing(slot -> InteractionHandler.getStackFromSlot(slot).method_7964().getString())),
    @SuppressWarnings("unused") ITEM_TYPE("item_type", Comparator.comparing(slot -> class_1792.method_7880(InteractionHandler.getStackFromSlot(slot).method_7909())));

    private final String translationKey;
    private final Comparator<Integer> comparator;

    SortingMode(String translationKey, Comparator<Integer> comparator) {
        this.translationKey = "sorting.mode." + translationKey;
        this.comparator = comparator;
    }

    public Comparator<Integer> getComparator() {
        return this.comparator
                .thenComparing(slot -> InteractionHandler.getStackFromSlot(slot).method_7947(), Comparator.reverseOrder())
                .thenComparing(slot -> {
                    class_1799 stack = InteractionHandler.getStackFromSlot(slot);
                    class_9304 component = stack.method_57824(class_9334.field_49643);
                    if (component == null) component = stack.method_57824(class_9334.field_49633);
                    if (component != null) {
                        class_9304 finalComponent = component;
                        return component.method_57534()
                                .stream()
                                .map(entry -> {
                                    if (entry.method_40230().isPresent()) {
                                        class_1887 enchantment = class_7923.field_41176.method_29107(entry.method_40230().get());
                                        if (enchantment != null) return enchantment.method_8179(0).getString() + " " + finalComponent.method_57536(enchantment);
                                    } return "";
                                })
                                .collect(Collectors.joining(", "));
                    }
                    return "";
                });
    }



    @Override
    public class_2561 getButtonText() {
        return class_2561.method_43471(ConfigManager.OPTION_TRANSLATION_KEY + "." + this.translationKey);
    }

    @Override
    public String getTranslationKey() {
        return this.translationKey;
    }
}

==> inventive-inventory-1.3.3-sources.jar: net/inventive_mods/inventive_inventory/config/enums/sorting/SortingMode.java <==
package net.inventive_mods.inventive_inventory.config.enums.sorting;

import net.inventive_mods.inventive_inventory.config.ConfigManager;
import net.inventive_mods.inventive_inventory.config.enums.accessors.Translatable;
import net.inventive_mods.inventive_inventory.util.InteractionHandler;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1887;
import net.minecraft.class_2561;
import net.minecraft.class_9304;
import net.minecraft.class_9334;
import java.util.Comparator;
import java.util.stream.Collectors;

public enum SortingMode implements Translatable {
    NAME("name", Comparator.comparing(slot -> InteractionHandler.getStackFromSlot(slot).method_7964().getString())),
    @SuppressWarnings("unused") ITEM_TYPE("item_type", Comparator.comparing(slot -> class_1792.method_7880(InteractionHandler.getStackFromSlot(slot).method_7909())));

    private final String translationKey;
    private final Comparator<Integer> comparator;

    SortingMode(String translationKey, Comparator<Integer> comparator) {
        this.translationKey = "sorting.mode." + translationKey;
        this.comparator = comparator;
    }

    public Comparator<Integer> getComparator() {
        return this.comparator
                .thenComparing(slot -> InteractionHandler.getStackFromSlot(slot).method_7947(), Comparator.reverseOrder())
                .thenComparing(slot -> {
                    class_1799 stack = InteractionHandler.getStackFromSlot(slot);
                    class_9304 component = stack.method_57824(class_9334.field_49643);
                    if (component == null) component = stack.method_57824(class_9334.field_49633);
                    if (component != null) {
                        class_9304 finalComponent = component;
                        return component.method_57534()
                                .stream()
                                .map(entry -> class_1887.method_8179(entry, 0).getString() + " " + finalComponent.method_57536(entry))
                                .collect(Collectors.joining(", "));
                    }
                    return "";
                });
    }



    @Override
    public class_2561 getButtonText() {
        return class_2561.method_43471(ConfigManager.OPTION_TRANSLATION_KEY + "." + this.translationKey);
    }

    @Override
    public String getTranslationKey() {
        return this.translationKey;
    }
}
